@@ -1,8 +1,6 @@
-from enum import Enum
 from typing import *
 import copy
 import datetime
-#from ww import f
 
 
 def handle_key_not_found(d: dict, key: str):
@@ -165,7 +163,7 @@ class EnumValue:
         return self.value
 
     def set_value(self, value: int) -> None:
-        self.value = value
+        self.value = int(value)
 
     def __hash__(self):
         return hash((self.name, self.creation_date))
@@ -178,12 +176,12 @@ class Enum:
     associations.
     """
 
-    def __init__(self: Enum) -> None:
+    def __init__(self) -> None:
         self.name = ""
         self.enumeration = {}
         self.creation_date = datetime.datetime.now()
 
-    def compile(self: Enum) -> Dict[str, Any]:
+    def compile(self) -> Dict[str, Any]:
         enums = {}
 
         for k, v in self.enumeration.items():
@@ -206,7 +204,6 @@ class Enum:
 
         for k,v in enumeration.items():
             enum_value = EnumValue()
-            print(v)
             enum_value.decompile(v)
             self.enumeration[k] = enum_value
     
@@ -221,6 +218,9 @@ class Enum:
 
     def set_value(self, name: int) -> None:
         self.value = value
+    
+    def normalize(self):
+        normalize(self.enumeration)
 
     def __hash__(self):
         return hash((self.name, self.creation_date))
@@ -269,7 +269,7 @@ class Spec:
         if enum.name in self.enums.keys():
             return False
 
-        self.enums[enum.name] = log
+        self.enums[enum.name] = enum
 
         return True
 
@@ -324,6 +324,8 @@ class Spec:
             self.rm_log(node)
         elif type(node) == Enum:
             self.rm_enum(node)
+        elif type(node) == EnumValue:
+            self.rm_enum_value(node)
 
     def rm_device(self, device: "Device") -> None:
         """ Remove a Device from Spec.
@@ -427,6 +429,21 @@ class Spec:
         for name in enums:
             del self.enums[name]
 
+    def rm_enum_value(self, enum_value):
+        """ Remove a Enum from Spec.
+
+        :param log: EnumValue to be removed.
+        """
+
+        for e in self.enums.values():
+            enum_values = []
+            for ev in e.enumeration.values():
+                if enum_value is ev:
+                    enum_values.append(ev.name)
+
+            for name in enum_values:
+                del e.enumeration[name]
+
     def compile(self) -> Dict[str, Any]:
         """ Transform python class node to its dictionary representation.
 
@@ -482,7 +499,10 @@ class Spec:
 
         normalize(self.devices)
         normalize(self.logs)
+
         normalize(self.enums)
+        for enum in self.enums.values():
+            enum.normalize()
 
         for key, dev in self.devices.items():
             dev.normalize()
@@ -498,21 +518,22 @@ class Spec:
 
 
 class Signal:
-    """ Signal node. Represents a CAN signal, similar to a DBC signal.
-        
-        :param name: Name of the Signal.
-        :param start: Start bit
-        :param length: Signal bit size.
-        :param scale: Scaling applied to the signal's data.
-        :param offset: Offset applied to the signal's data.
-        :param unit: Unit of the Signal after applying scaling and offset.
-        :param comment: Description of the Signal.
-        :param min_value: Minimum value allowed to the Signal's data.
-        :param max_value: Maximum value allowed to the Signal's data.
-        :param type: Type of the Signal's data.
-        :param mux: Name of the mux Signal. None if the Signal doesn't belong
-        to a multiplexed Message.
-        :param mux_count: Number of signals that the mux can reference for this Muxed signal.
+    """ 
+    Signal node. Represents a CAN signal, similar to a DBC signal.
+            
+    :param name: Name of the Signal.
+    :param start: Start bit
+    :param length: Signal bit size.
+    :param scale: Scaling applied to the signal's data.
+    :param offset: Offset applied to the signal's data.
+    :param unit: Unit of the Signal after applying scaling and offset.
+    :param comment: Description of the Signal.
+    :param min_value: Minimum value allowed to the Signal's data.
+    :param max_value: Maximum value allowed to the Signal's data.
+    :param type: Type of the Signal's data.
+    :param mux: Name of the mux Signal. None if the Signal doesn't belong to a multiplexed Message.
+    :param mux_count: Number of signals that the mux can reference for this Muxed signal.
+
 
     """
 
@@ -1346,10 +1367,10 @@ class Device:
     def __repr__(self):
         return (
             "{"
-            + f("""
+            + f"""
     name: {self.name}, 
     id: {self.id}
-""")
+"""
             + "}"
         )
 
@@ -1434,6 +1455,7 @@ class Common:
         return hash((self.name, self.id, self.creation_date))
 
 
+
 def make_sid(dev_id: int, msg_id: int) -> int:
     """ Find the sid from the dev_id and the msg_id """
     return msg_id * 32 + dev_id
